==> kubernetes-model-metrics-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/metrics/v1beta1/NodeMetricsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.metrics.v1beta1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.Quantity;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class NodeMetricsFluentImpl<A extends io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent<A>{
  public NodeMetricsFluentImpl() {
  }
  public NodeMetricsFluentImpl(io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetrics instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withTimestamp(instance.getTimestamp()); 
    this.withUsage(instance.getUsage()); 
    this.withWindow(instance.getWindow()); 
  }
  private java.lang.String apiVersion;
  private java.lang.String kind;
  private io.fabric8.kubernetes.api.model.ObjectMetaBuilder metadata;
  private java.lang.String timestamp;
  private java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> usage;
  private io.fabric8.kubernetes.api.model.Duration window;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent.MetadataNested<A> withNewMetadata() {
    return new io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluentImpl.MetadataNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return new io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluentImpl.MetadataNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.kubernetes.api.model.ObjectMetaBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  public java.lang.String getTimestamp() {
    return this.timestamp;
  }
  public A withTimestamp(java.lang.String timestamp) {
    this.timestamp=timestamp; return (A) this;
  }
  public java.lang.Boolean hasTimestamp() {
    return this.timestamp != null;
  }
  
  /**
   * Method is deprecated. use withTimestamp instead.
   */
  @java.lang.Deprecated
  public A withNewTimestamp(java.lang.String arg0) {
    return (A)withTimestamp(new String(arg0));
  }
  public A addToUsage(java.lang.String key,io.fabric8.kubernetes.api.model.Quantity value) {
    if(this.usage == null && key != null && value != null) { this.usage = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(key != null && value != null) {this.usage.put(key, value);} return (A)this;
  }
  public A addToUsage(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.usage == null && map != null) { this.usage = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(map != null) { this.usage.putAll(map);} return (A)this;
  }
  public A removeFromUsage(java.lang.String key) {
    if(this.usage == null) { return (A) this; }
    if(key != null && this.usage != null) {this.usage.remove(key);} return (A)this;
  }
  public A removeFromUsage(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.usage == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.usage != null){this.usage.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> getUsage() {
    return this.usage;
  }
  public <K,V>A withUsage(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> usage) {
    if (usage == null) { this.usage =  null;} else {this.usage = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(usage);} return (A) this;
  }
  public java.lang.Boolean hasUsage() {
    return this.usage != null;
  }
  public io.fabric8.kubernetes.api.model.Duration getWindow() {
    return this.window;
  }
  public A withWindow(io.fabric8.kubernetes.api.model.Duration window) {
    this.window=window; return (A) this;
  }
  public java.lang.Boolean hasWindow() {
    return this.window != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NodeMetricsFluentImpl that = (NodeMetricsFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (timestamp != null ? !timestamp.equals(that.timestamp) :that.timestamp != null) return false;
    if (usage != null ? !usage.equals(that.usage) :that.usage != null) return false;
    if (window != null ? !window.equals(that.window) :that.window != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  timestamp,  usage,  window,  super.hashCode());
  }
  public class MetadataNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl<io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent.MetadataNested<N>> implements io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetadataNestedImpl(io.fabric8.kubernetes.api.model.ObjectMeta item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectMetaBuilder builder;
    public N and() {
      return (N) NodeMetricsFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-metrics-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/metrics/v1beta1/NodeMetricsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.metrics.v1beta1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.Quantity;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class NodeMetricsFluentImpl<A extends io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent<A>{
  public NodeMetricsFluentImpl() {
  }
  public NodeMetricsFluentImpl(io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetrics instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withTimestamp(instance.getTimestamp()); 
    this.withUsage(instance.getUsage()); 
    this.withWindow(instance.getWindow()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiVersion;
  private java.lang.String kind;
  private io.fabric8.kubernetes.api.model.ObjectMetaBuilder metadata;
  private java.lang.String timestamp;
  private java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> usage;
  private io.fabric8.kubernetes.api.model.Duration window;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent.MetadataNested<A> withNewMetadata() {
    return new io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluentImpl.MetadataNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return new io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluentImpl.MetadataNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.kubernetes.api.model.ObjectMetaBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  public java.lang.String getTimestamp() {
    return this.timestamp;
  }
  public A withTimestamp(java.lang.String timestamp) {
    this.timestamp=timestamp; return (A) this;
  }
  public java.lang.Boolean hasTimestamp() {
    return this.timestamp != null;
  }
  
  /**
   * Method is deprecated. use withTimestamp instead.
   */
  @java.lang.Deprecated
  public A withNewTimestamp(java.lang.String arg0) {
    return (A)withTimestamp(new String(arg0));
  }
  public A addToUsage(java.lang.String key,io.fabric8.kubernetes.api.model.Quantity value) {
    if(this.usage == null && key != null && value != null) { this.usage = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(key != null && value != null) {this.usage.put(key, value);} return (A)this;
  }
  public A addToUsage(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.usage == null && map != null) { this.usage = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(map != null) { this.usage.putAll(map);} return (A)this;
  }
  public A removeFromUsage(java.lang.String key) {
    if(this.usage == null) { return (A) this; }
    if(key != null && this.usage != null) {this.usage.remove(key);} return (A)this;
  }
  public A removeFromUsage(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.usage == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.usage != null){this.usage.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> getUsage() {
    return this.usage;
  }
  public <K,V>A withUsage(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> usage) {
    if (usage == null) { this.usage =  null;} else {this.usage = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(usage);} return (A) this;
  }
  public java.lang.Boolean hasUsage() {
    return this.usage != null;
  }
  public io.fabric8.kubernetes.api.model.Duration getWindow() {
    return this.window;
  }
  public A withWindow(io.fabric8.kubernetes.api.model.Duration window) {
    this.window=window; return (A) this;
  }
  public java.lang.Boolean hasWindow() {
    return this.window != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NodeMetricsFluentImpl that = (NodeMetricsFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (timestamp != null ? !timestamp.equals(that.timestamp) :that.timestamp != null) return false;
    if (usage != null ? !usage.equals(that.usage) :that.usage != null) return false;
    if (window != null ? !window.equals(that.window) :that.window != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  timestamp,  usage,  window,  additionalProperties,  super.hashCode());
  }
  public class MetadataNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl<io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent.MetadataNested<N>> implements io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetadataNestedImpl(io.fabric8.kubernetes.api.model.ObjectMeta item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectMetaBuilder builder;
    public N and() {
      return (N) NodeMetricsFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  
}
